/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.application;

import java.util.EventListener;

/**
 * Interface for listeners that want to be notified on Announcement Insertion
 * events.
 * 
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:AnnouncementListener.java 220 2006-03-06 14:46:23Z bombe $
 */
public interface AnnouncementListener extends EventListener {

	/**
	 * Notifies listeners that the announcement insert started.
	 * 
	 * @param key
	 *            The key the announcement is inserted to
	 */
	public void announcementInsertStarted(String key);

	/**
	 * Notifies listeners that the announcement insertion to the specified key
	 * failed.
	 * 
	 * @param key
	 *            The key the announcement was about to be inserted to
	 * @param exception
	 *            The exception that prevented insertion
	 */
	public void announcementInsertFailed(String key, Exception exception);

	/**
	 * Notifies listeners that the announcement was successfully inserted to the
	 * specified key.
	 * 
	 * @param key
	 *            The key the announcement was inserted to
	 */
	public void announcementInsertComplete(String key);

}
