/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.application;

import java.util.EventListener;

/**
 * Interface for listeners that want to be notified on discovery events.
 * Discovery events are generated when announcement information from other
 * clients has been found (or not found).
 * 
 * @see de.todesbaum.freemule.application.DiscoveryService
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:DiscoveryListener.java 220 2006-03-06 14:46:23Z bombe $
 */
public interface DiscoveryListener extends EventListener {

	/**
	 * Notifies listeners that the search for announcement information at the
	 * specified key has begun.
	 * 
	 * @param key
	 *            The key of the announcement information
	 */
	public void discoveryStarted(String key);

	/**
	 * Notifies listeners that the search for announcement information at the
	 * specified key failed. The reason might something as transient as an
	 * {@link de.todesbaum.util.freenet.fcp.FcpRouteNotFoundException} so this should not always
	 * be treated as fatality.
	 * 
	 * @param key
	 *            The key of the announcement information
	 * @param exception
	 *            The exception that prevented getting the information
	 */
	public void discoveryFailed(String key, Exception exception);

	/**
	 * Notifies listeners that announcement information has been found.
	 * 
	 * @param key
	 *            The key of the announcement information
	 * @param remoteClient
	 *            The client that sent the information
	 */
	public void discoveryComplete(String key, Client remoteClient);

}
