/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.application;

import java.util.EventListener;

/**
 * Interface for listeners that want to be notified on filelist collecting
 * events.
 * 
 * @see de.todesbaum.freemule.application.FilelistCollectorService
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id: FilelistCollectorListener.java,v 1.1 2005/11/28 22:50:39 bombe
 *          Exp $
 */
public interface FilelistCollectorListener extends EventListener {

	/**
	 * Notifies listeners that the collecting of a filelist has started.
	 * 
	 * @param remoteClient
	 *            The client of the filelist
	 * @param key
	 *            The key of the filelist
	 */
	public void filelistCollectingStarted(Client remoteClient, String key);

	/**
	 * Notifies listeners that the collecting of a filelist has failed
	 * 
	 * @param remoteClient
	 *            The client of the filelist
	 * @param key
	 *            The key of the filelist
	 * @param exception
	 *            The exception that caused collecting to fail
	 */
	public void filelistCollectingFailed(Client remoteClient, String key, Exception exception);

	/**
	 * Notifies listeners that the collecting of a filelist has completed
	 * successfully.
	 * 
	 * @param remoteClient
	 *            The client of the filelist
	 * @param key
	 *            The key of the filelist
	 * @param sharedFiles
	 *            The filelist of the client
	 */
	public void filelistCollectingComplete(Client remoteClient, String key, SharedFile[] sharedFiles);

}
