/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.application;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;

/**
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:UploadRequest.java 220 2006-03-06 14:46:23Z bombe $
 */
public class UploadRequest {

	private String clientId;
	private long timestamp;
	private List<String> keys;
	private List<BitSet> blockLists;

	/**
	 * 
	 */
	public UploadRequest(String clientId, long timestamp) {
		this.clientId = clientId;
		this.timestamp = timestamp;
		keys = new ArrayList<String>();
		blockLists = new ArrayList<BitSet>();
	}

	/**
	 * @return Returns the clientId.
	 */
	public String getClientId() {
		return clientId;
	}

	public long getTimestamp() {
		return timestamp;
	}
	
	public synchronized int size() {
		return keys.size();
	}
	
	public synchronized void addKey(String key, BitSet blockList) {
		keys.add(key);
		blockLists.add(blockList);
	}
	
	public void touch() {
		timestamp = System.currentTimeMillis();
	}
	
	/**
	 * @return Returns the hash.
	 */
	public synchronized String getKey(int index) {
		return keys.get(index);
	}

	/**
	 * @return Returns the blockList.
	 */
	public synchronized BitSet getBlockList(int index) {
		return blockLists.get(index);
	}

	/**
	 * @param key
	 */
	public synchronized void remove(String key) {
		int keyIndex = keys.indexOf(key);
		if (keyIndex != -1) {
			keys.remove(keyIndex);
			blockLists.remove(keyIndex);
		}
	}

	/**
	 * @param uploadRequest
	 */
	public void merge(UploadRequest uploadRequest) {
		for (int index = 0, count = uploadRequest.size(); index < count; index++) {
			String key = uploadRequest.getKey(index);
			int keyPosition = keys.indexOf(key);
			if (keyPosition == -1) {
				addKey(key, uploadRequest.getBlockList(index));
			} else {
				blockLists.get(index).or(uploadRequest.getBlockList(index));
			}
		}
	}

}
