/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.gui;

import java.awt.BorderLayout;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;

import de.todesbaum.freemule.application.Client;
import de.todesbaum.freemule.application.ClientListener;
import de.todesbaum.freemule.application.ClientService;
import de.todesbaum.freemule.application.FilelistListener;
import de.todesbaum.freemule.application.FilelistService;
import de.todesbaum.freemule.application.SharedFile;
import de.todesbaum.freemule.util.NumberFormatter;


/**
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:KnownClientsPanel.java 221 2006-03-06 14:46:49Z bombe $
 */
public class KnownClientsPanel extends JPanel implements ClientListener, FilelistListener {

	private JFrame mainFrame;
	private JTable knownClientsTable;
	private TableSorter knownClientsSorter;
	private JLabel summaryLabel;
	private KnownClientsTableModel knownClientsTableModel;

	private ClientService clientService;
	private FilelistService filelistService;

	public KnownClientsPanel(JFrame mainFrame) {
		super(new BorderLayout(5, 5));
		initializeComponents();
		initializeLayout();
	}

	private void initializeComponents() {
		knownClientsTableModel = new KnownClientsTableModel();
		knownClientsSorter = new TableSorter(knownClientsTableModel);
		knownClientsTable = new JTable(knownClientsSorter);
		knownClientsSorter.setTableHeader(knownClientsTable.getTableHeader());
		summaryLabel = new JLabel();
		summaryLabel.setBorder(new CompoundBorder(new EtchedBorder(EtchedBorder.LOWERED), new EmptyBorder(1, 1, 1, 1)));
	}

	private void initializeLayout() {
		setBorder(new EmptyBorder(5, 5, 5, 5));
		add(new JScrollPane(knownClientsTable), BorderLayout.CENTER);
		add(summaryLabel, BorderLayout.PAGE_END);
	}

	public void setClientService(ClientService clientService) {
		if (this.clientService != null) {
			this.clientService.removeClientListener(this);
		}
		this.clientService = clientService;
		if (this.clientService != null) {
			this.clientService.addClientListener(this);
		}
		knownClientsTableModel.setClientService(clientService);
		updateSummaryLabel();
	}

	public void setFilelistService(FilelistService filelistService) {
		if (this.filelistService != null) {
			this.filelistService.removeFilelistListener(this);
		}
		this.filelistService = filelistService;
		if (this.filelistService != null) {
			this.filelistService.addFilelistListener(this);
		}
		knownClientsTableModel.setFilelistService(filelistService);
		updateSummaryLabel();
	}

	private void updateSummaryLabel() {
		if ((clientService == null) || (filelistService == null)) {
			summaryLabel.setText("Number of Clients: 0, Number of Files: 0, Number of Bytes: 0 Bytes (0.0 Bytes)");
		}
		Client[] clients = clientService.getClients();
		int fileCount = 0;
		long byteCount = 0;
		for (Client client: clients) {
			SharedFile[] sharedFiles = filelistService.getClientFilelist(client);
			if (sharedFiles != null) {
				fileCount += sharedFiles.length;
				for (SharedFile sharedFile: sharedFiles) {
					byteCount += sharedFile.getLength();
				}
			}
		}
		summaryLabel.setText("Number of Clients: " + clients.length + ", Number of Files: " + fileCount + ", Number of Bytes: " + byteCount + " Bytes (" + NumberFormatter.format(byteCount) + ")");
	}

	//
	// INTERFACE ClientListener
	//

	/**
	 * {@inheritDoc}
	 */
	public void clientAdded(Client remoteClient) {
		updateSummaryLabel();
	}

	/**
	 * {@inheritDoc}
	 */
	public void clientUpdated(Client remoteClient) {
		updateSummaryLabel();
	}

	/**
	 * {@inheritDoc}
	 */
	public void clientRemoved(Client remoteClient) {
		updateSummaryLabel();
	}

	//
	// INTERFACE FilelistListener
	//

	/**
	 * {@inheritDoc}
	 */
	public void filelistAdded(Client remoteClient, SharedFile[] sharedFiles) {
		updateSummaryLabel();
	}

	/**
	 * {@inheritDoc}
	 */
	public void filelistUpdated(Client remoteClient, SharedFile[] sharedFiles) {
		updateSummaryLabel();
	}

	/**
	 * {@inheritDoc}
	 */
	public void filelistRemoved(Client remoteClient) {
		updateSummaryLabel();
	}

}
