/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.gui;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager;

/**
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:LineLayout.java 221 2006-03-06 14:46:49Z bombe $
 */
public class LineLayout implements LayoutManager {

	private int vgap;

	public LineLayout() {
		this(5);
	}

	public LineLayout(int vgap) {
		this.vgap = vgap;
	}

	/**
	 * @see java.awt.LayoutManager#addLayoutComponent(java.lang.String,
	 *      java.awt.Component)
	 */
	public void addLayoutComponent(String name, Component comp) {
	}

	/**
	 * @see java.awt.LayoutManager#removeLayoutComponent(java.awt.Component)
	 */
	public void removeLayoutComponent(Component comp) {
	}

	/**
	 * @see java.awt.LayoutManager#preferredLayoutSize(java.awt.Container)
	 */
	public Dimension preferredLayoutSize(Container container) {
		int width = 0;
		int height = 0;
		boolean firstComponent = true;
		for (int cCount = 0, cSize = container.getComponentCount(); cCount < cSize; cCount++) {
			Component component = container.getComponent(cCount);
			if (component.isVisible()) {
				Dimension preferredSize = component.getPreferredSize();
				width = (preferredSize.width > width) ? preferredSize.width : width;
				height += preferredSize.height + (firstComponent ? 0 : vgap);
				firstComponent = false;
			}
		}
		Insets insets = container.getInsets();
		return new Dimension(width + (insets.left + insets.right), height + (insets.top + insets.bottom));
	}

	/**
	 * @see java.awt.LayoutManager#minimumLayoutSize(java.awt.Container)
	 */
	public Dimension minimumLayoutSize(Container container) {
		int width = 0;
		int height = 0;
		boolean firstComponent = true;
		for (int cCount = 0, cSize = container.getComponentCount(); cCount < cSize; cCount++) {
			Component component = container.getComponent(cCount);
			if (component.isVisible()) {
				Dimension minimumSize = component.getMinimumSize();
				width = (minimumSize.width > width) ? minimumSize.width : width;
				height += minimumSize.height + (firstComponent ? 0 : vgap);
				firstComponent = false;
			}
		}
		Insets insets = container.getInsets();
		return new Dimension(width + (insets.left + insets.right), height + (insets.top + insets.bottom));
	}

	/**
	 * @see java.awt.LayoutManager#layoutContainer(java.awt.Container)
	 */
	public void layoutContainer(Container container) {
		Insets insets = container.getInsets();
		int height = insets.top;
		for (int cCount = 0, cSize = container.getComponentCount(); cCount < cSize; cCount++) {
			Component component = container.getComponent(cCount);
			if (component.isVisible()) {
				component.setLocation(insets.left, height);
				component.setSize(container.getSize().width - (insets.left + insets.right), component.getPreferredSize().height);
				height += component.getSize().height + vgap;
			}
		}
	}

}
