/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.gui;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;

import de.todesbaum.freemule.application.Client;
import de.todesbaum.freemule.application.DownloadService;
import de.todesbaum.freemule.application.FilelistService;
import de.todesbaum.freemule.application.SharedFile;
import de.todesbaum.freemule.gui.SearchResultTableModel.ResultFile;


/**
 * @author <a href="mailto:droden@gmail.com">David Roden</a>
 * @version $Id:SearchPanel.java 221 2006-03-06 14:46:49Z bombe $
 */
public class SearchPanel extends JPanel {

	private JFrame mainFrame;

	private Action searchAction;
	private Action closeTabAction;

	private JTextField searchTextField;
	private JTextField searchMinimumSizeTextField;
	private JTextField searchMaximumSizeTextField;
	private JCheckBox searchRegularExpression;
	private JCheckBox searchCaseSensitive;
	private JCheckBox searchMinimumSize;
	private JCheckBox searchMaximumSize;

	private JButton searchButton;

	private JTabbedPane searchTabbedPane;

	private FilelistService filelistService;
	private DownloadService downloadService;

	public SearchPanel(JFrame mainFrame) {
		super(new BorderLayout(5, 5));
		this.mainFrame = mainFrame;
		initializeActions();
		initializeComponents();
		initializeLayout();
	}

	private void initializeComponents() {
		searchTextField = new JTextField();
		searchTextField.addActionListener(searchAction);
		searchRegularExpression = new JCheckBox("Regular Expression");
		searchRegularExpression.setEnabled(false);
		searchCaseSensitive = new JCheckBox("Case Sensitive");
		searchCaseSensitive.setEnabled(false);
		searchMinimumSize = new JCheckBox("Minimum Size");
		searchMinimumSize.setEnabled(false);
		searchMinimumSizeTextField = new JTextField(7);
		searchMinimumSizeTextField.setEnabled(false);
		searchMaximumSize = new JCheckBox("Maximum Size");
		searchMaximumSize.setEnabled(false);
		searchMaximumSizeTextField = new JTextField(7);
		searchMaximumSizeTextField.setEnabled(false);
		searchButton = new JButton(searchAction);
		searchTabbedPane = new JTabbedPane();
	}

	private void initializeLayout() {
		setBorder(new EmptyBorder(5, 5, 5, 5));
		add(createTopPanel(), BorderLayout.PAGE_START);
		add(searchTabbedPane, BorderLayout.CENTER);
		add(createButtonPanel(), BorderLayout.PAGE_END);
	}

	private JComponent createTopPanel() {
		Box topPanel = new Box(BoxLayout.PAGE_AXIS);
		topPanel.add(createSearchTextPanel());
		topPanel.add(Box.createVerticalStrut(5));
		topPanel.add(createOptionsPanel());
		return topPanel;
	}

	private JComponent createSearchTextPanel() {
		JPanel searchTextPanel = new JPanel(new BorderLayout(5, 5));
		searchTextPanel.add(new JLabel("Search Text:"), BorderLayout.LINE_START);
		searchTextPanel.add(searchTextField, BorderLayout.CENTER);
		searchTextPanel.add(searchButton, BorderLayout.LINE_END);
		return searchTextPanel;
	}

	private JComponent createButtonPanel() {
		JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.TRAILING, 5, 5));
		buttonPanel.setBorder(new EmptyBorder(-5, -5, -5, -5));
		buttonPanel.add(new JButton(closeTabAction));
		return buttonPanel;
	}

	private JComponent createOptionsPanel() {
		JPanel optionsPanel = new JPanel(new BorderLayout(5, 5));
		optionsPanel.add(new JLabel("Options"), BorderLayout.LINE_START);
		optionsPanel.add(createOptionsField(), BorderLayout.CENTER);
		return optionsPanel;
	}

	private JComponent createOptionsField() {
		Box optionsField = Box.createVerticalBox();
		optionsField.setBorder(new EtchedBorder());
		Box firstLine = Box.createHorizontalBox();
		optionsField.add(firstLine);
		firstLine.add(searchRegularExpression);
		firstLine.add(Box.createHorizontalStrut(5));
		firstLine.add(searchCaseSensitive);
		optionsField.add(Box.createVerticalStrut(5));
		Box secondLine = Box.createHorizontalBox();
		optionsField.add(secondLine);
		secondLine.add(searchMinimumSize);
		secondLine.add(searchMinimumSizeTextField);
		secondLine.add(Box.createHorizontalStrut(5));
		secondLine.add(searchMaximumSize);
		secondLine.add(searchMaximumSizeTextField);
		optionsField.add(Box.createVerticalStrut(5));
		return optionsField;
	}

	private void initializeActions() {
		searchAction = new AbstractAction("Search") {

			public void actionPerformed(java.awt.event.ActionEvent e) {
				actionSearch();
			}
		};

		closeTabAction = new AbstractAction("Close Tab") {

			public void actionPerformed(ActionEvent actionEvent) {
				actionCloseTab();
			}
		};
		closeTabAction.setEnabled(false);
	}

	public void setDownloadService(DownloadService downloadService) {
		this.downloadService = downloadService;
	}

	public void setFilelistService(FilelistService filelistService) {
		this.filelistService = filelistService;
	}
	
	protected void actionSearch() {
		if (filelistService.getClients().length == 0) {
			JOptionPane.showMessageDialog(mainFrame, "No filelist have been found, so you won't find anything.", "", JOptionPane.WARNING_MESSAGE);
			return;
		}
		String text = searchTextField.getText();
		searchTextField.setText("");

		SearchResultPanel resultPanel = new SearchResultPanel(mainFrame);
		resultPanel.setDownloadService(downloadService);
		searchTabbedPane.addTab(text, resultPanel);
		searchTabbedPane.setSelectedIndex(searchTabbedPane.getTabCount() - 1);
		closeTabAction.setEnabled(true);

		Client[] clients = filelistService.getClients();
		for (Client client: clients) {
			SharedFile[] clientFiles = filelistService.getClientFilelist(client);
			for (SharedFile sharedFile: clientFiles) {
				if (sharedFile.getName().toUpperCase().contains(text.toUpperCase())) {
					ResultFile resultFile = new ResultFile(client, sharedFile.getName(), sharedFile.getLength(), sharedFile.getKey(), sharedFile.getComment(), sharedFile.getRating(), sharedFile.getBlockCount());
					resultPanel.addResultFile(resultFile);
				}
			}
		}
	}

	protected void actionCloseTab() {
		int selectedTab = searchTabbedPane.getSelectedIndex();
		if (selectedTab != -1) {
			searchTabbedPane.removeTabAt(selectedTab);
			closeTabAction.setEnabled(searchTabbedPane.getTabCount() > 0);
		}
	}

}
