/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.main;

import de.todesbaum.freemule.application.ConfigurationListener;
import de.todesbaum.freemule.application.FreeMule;
import de.todesbaum.freemule.gui.MainFrame;
import de.todesbaum.util.splash.Splash;

/**
 * FreeMule starter class. Loads the configuration, creates a {@link FreeMule} instance and starts it.
 * 
 * @author <a href="mailto:droden@gmail.com">David Roden </a>
 * @version $Id:Main.java 221 2006-03-06 14:46:49Z bombe $
 */
public class Main implements ConfigurationListener {

	/** The current configuration. */
	private Configuration configuration;

	/**
	 * Constructor of starter class. Does everything.
	 */
	public Main() {
		Splash splashScreen = new Splash("/img/splash3.png");
		configuration = new Configuration();
		configuration.load();

		FreeMule freeMule = new FreeMule();
		freeMule.init();
		freeMule.addConfigurationListener(this);
		freeMule.setPrivateKey(configuration.getPrivateKey());
		freeMule.setPublicKey(configuration.getPublicKey());
		freeMule.setEntropy(configuration.getEntropy());
		freeMule.setUsername(configuration.getUsername());
		freeMule.setNodeAddress(configuration.getNodeAddress());
		freeMule.setNodePort(configuration.getNodePort());
		freeMule.setNetworkName(configuration.getNetworkName());
		freeMule.setHopsToLive(configuration.getHopsToLive());
		freeMule.setIncomingDirectory(configuration.getIncomingDirectory());
		freeMule.setTempDirectory(configuration.getTempDirectory());
		freeMule.setSharedDirectories(configuration.getSharedDirectories());
		freeMule.setFilelistIndex(configuration.getFilelistIndex());
		freeMule.setFilelistLastInsertedVersion(configuration.getFilelistLastInsertedVersion());

		MainFrame mainFrame = new MainFrame(freeMule);
		mainFrame.setConfiguration(configuration);
		splashScreen.setVisible(false);
		mainFrame.setVisible(true);
	}

	/**
	 * This method gets called by {@link FreeMule} if a value that needs to be persistent has changed.
	 * 
	 * @param freeMule
	 *            The {@link FreeMule} object that changed one its persistent values
	 */
	public void configurationChanged(FreeMule freeMule) {
		configuration.setPrivateKey(freeMule.getPrivateKey());
		configuration.setPublicKey(freeMule.getPublicKey());
		configuration.setEntropy(freeMule.getEntropy());
		configuration.setUsername(freeMule.getUsername());
		configuration.setNodeAddress(freeMule.getNodeAddress());
		configuration.setNodePort(freeMule.getNodePort());
		configuration.setNetworkName(freeMule.getNetworkName());
		configuration.setHopsToLive(freeMule.getHopsToLive());
		configuration.setIncomingDirectory(freeMule.getIncomingDirectory());
		configuration.setTempDirectory(freeMule.getTempDirectory());
		configuration.setSharedDirectories(freeMule.getSharedDirectories());
		configuration.setFilelistIndex(freeMule.getFilelistIndex());
		configuration.setFilelistLastInsertedVersion(freeMule.getFilelistLastInsertedVersion());
		configuration.save();
	}

	/**
	 * Start method that gets called by the VM upon start.
	 * 
	 * @param args
	 *            The command line
	 */
	public static void main(String[] args) {
		new Main();
	}

}
