/*
 * This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59
 * Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.freemule.util;

import junit.framework.TestCase;

/**
 * @author David Roden &lt;droden@gmail.com&gt;
 * @version $Id$
 */
public class StringUtilsTest extends TestCase {

	/*
	 * Test method for 'freemule.network.ConnectionHandler.splitLineIntoWords(String)'
	 */
	public void testSplitLineIntoWords() {
		String[] words = null;

		words = StringUtils.splitLineIntoWords("You have no choice.");
		assertEquals("sentence 1 length", 4, words.length);
		assertEquals("sentence 1 word 1", "You", words[0]);
		assertEquals("sentence 1 word 2", "have", words[1]);
		assertEquals("sentence 1 word 3", "no", words[2]);
		assertEquals("sentence 1 word 4", "choice.", words[3]);

		words = StringUtils.splitLineIntoWords(" You   have   no      choice. ");
		assertEquals("sentence 2 length", 4, words.length);
		assertEquals("sentence 2 word 1", "You", words[0]);
		assertEquals("sentence 2 word 2", "have", words[1]);
		assertEquals("sentence 2 word 3", "no", words[2]);
		assertEquals("sentence 2 word 4", "choice.", words[3]);

		words = StringUtils.splitLineIntoWords(" \"You\"   have   no      choice. ");
		assertEquals("sentence 3 length", 4, words.length);
		assertEquals("sentence 3 word 1", "You", words[0]);
		assertEquals("sentence 3 word 2", "have", words[1]);
		assertEquals("sentence 3 word 3", "no", words[2]);
		assertEquals("sentence 3 word 4", "choice.", words[3]);

		words = StringUtils.splitLineIntoWords(" \"You   have\"   no      choice. ");
		assertEquals("sentence 4 length", 3, words.length);
		assertEquals("sentence 4 word 1", "You   have", words[0]);
		assertEquals("sentence 4 word 2", "no", words[1]);
		assertEquals("sentence 4 word 3", "choice.", words[2]);

		words = StringUtils.splitLineIntoWords(" \"You \\\"  have\"   no      choice. ");
		assertEquals("sentence 5 length", 3, words.length);
		assertEquals("sentence 5 word 1", "You \"  have", words[0]);
		assertEquals("sentence 5 word 2", "no", words[1]);
		assertEquals("sentence 5 word 3", "choice.", words[2]);
	}

	public void testFormatWords() {
		String line;

		line = StringUtils.formatWords("You", "have", "no", "choice.");
		assertEquals("sentence 1 length", 19, line.length());
		assertEquals("sentence 1", "You have no choice.", line);

		line = StringUtils.formatWords("You have", "no", "choice.");
		assertEquals("sentence 2", "\"You have\" no choice.", line);

		line = StringUtils.formatWords("You have", "no", " choice.");
		assertEquals("sentence 3", "\"You have\" no \" choice.\"", line);
	}

}
