/*
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package de.todesbaum.util.freenet.fcp;

import java.io.IOException;
import java.io.OutputStream;

/**
 * @author David Roden <droden@gmail.com>
 * @version $Id: FcpGenerateSVKPair.java 218 2006-03-06 14:43:35Z  $
 */
public class FcpGenerateSVKPair extends FcpCommand {

	private String privateKey;
	private String publicKey;
	private String cryptoKey;

	/**
	 * @see de.todesbaum.util.freenet.fcp.FcpCommand#getName()
	 */
	public String getName() {
		return "GenerateSVKPair";
	}

	/**
	 * @return Returns the cryptoKey.
	 */
	public String getCryptoKey() {
		return cryptoKey;
	}

	/**
	 * @return Returns the privateKey.
	 */
	public String getPrivateKey() {
		return privateKey;
	}

	/**
	 * @return Returns the publicKey.
	 */
	public String getPublicKey() {
		return publicKey;
	}

	/**
	 * @see de.todesbaum.util.freenet.fcp.FcpCommand#writeCommand(java.io.OutputStream)
	 */
	public boolean writeCommand(OutputStream outputStream) throws IOException {
		return true;
	}

	/**
	 * @see de.todesbaum.util.freenet.fcp.FcpCommand#handleFcpMessage(de.todesbaum.util.freenet.fcp.FcpMessage)
	 */
	public void handleFcpMessage(FcpMessage fcpMessage) throws FcpException {
		if (fcpMessage.getName().equals("Success")) {
			publicKey = fcpMessage.getParameter("PublicKey");
			privateKey = fcpMessage.getParameter("PrivateKey");
			cryptoKey = fcpMessage.getParameter("CryptoKey");
			complete = true;
		}
	}

}
